@@ -238,6 +238,10 @@ gst_rtp_bin_class_init (GstRTPBinClass * klass)
     //gstelement_klass->provide_clock = gst_rtp_bin_provide_clock;
 
     GST_DEBUG_CATEGORY_INIT (gst_rtp_bin_debug, "rtpbin", 0, "RTP Bin");
+    
+    // this is not MT safe so it's exec only once here
+    if (!GST_TYPE_NETBUFFER) { g_error ("eek! the impossible happened!"); }
+    
 }
 
 static void
